﻿using System.Drawing;

using DevExpress.Utils.Drawing;
using DevExpress.Utils.Text;

namespace TestProject
{
    /// <summary>
    /// 뷰 정보
    /// </summary>
    public class ViewInfo
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 진행 폰트
        /// </summary>
        private Font progressFont = null;

        /// <summary>
        /// 브러시
        /// </summary>
        private Brush brush = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public
        
        #region 단계 - Stage

        /// <summary>
        /// 단계
        /// </summary>
        public string Stage { get; set; }

        #endregion
        #region 카운터 - Counter

        /// <summary>
        /// 카운터
        /// </summary>
        public int Counter { get; set; }

        #endregion
        #region 텍스트 - Text

        /// <summary>
        /// 텍스트
        /// </summary>
        public string Text
        {
            get
            {
                return string.Format("{0} - ({1}%)", Stage, Counter.ToString("D2"));
            }
        }

        #endregion
        #region 진행 레이블 폰트 - ProgressLabelFont

        /// <summary>
        /// 진행 레이블 폰트
        /// </summary>
        public Font ProgressLabelFont
        {
            get
            {
                if(this.progressFont == null)
                {
                    this.progressFont = new Font("나눔고딕코딩", 10);
                }

                return this.progressFont;
            }
        }

        #endregion
        #region 브러시 - Brush

        /// <summary>
        /// 브러시
        /// </summary>
        public Brush Brush
        {
            get
            {
                if(this.brush == null)
                {
                    this.brush = new SolidBrush(Color.Black);
                }

                return this.brush;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - ViewInfo()

        /// <summary>
        /// 생성자
        /// </summary>
        public ViewInfo()
        {
            Stage   = string.Empty;
            Counter = 1;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 진행 레이블 위치 계산하기 - CalculateProgressLabelPoint(graphicsCache, boundRectangle)

        /// <summary>
        /// 진행 레이블 위치 계산하기
        /// </summary>
        /// <param name="graphicsCache">그래픽스 캐시</param>
        /// <param name="boundRectangle">경계 사각형</param>
        /// <returns>진행 레이블 위치</returns>
        public PointF CalculateProgressLabelPoint(GraphicsCache graphicsCache, Rectangle boundRectangle)
        {
            const int yOffset = 40;

            Size size = TextUtils.GetStringSize(graphicsCache.Graphics, Text, ProgressLabelFont);

            return new Point(boundRectangle.Width / 2 - size.Width / 2, yOffset);
        }

        #endregion
    }
}